@@ -1,2 +1,2 @@
 from .utils import model_sync, producer, pick
-from .amqp import job_tasks
+from .amqp import job_tasks, JobClient
