@@ -37,7 +37,10 @@ class JobClient(object):
         self.channel.basic_publish(
             exchange=exchange,
             routing_key=routing_key,
-            body=json.dumps(body, default=str)
+            body=json.dumps(body, default=str),
+            properties=pika.BasicProperties(
+                delivery_mode=2,  # make message persistent
+            )
         )
 
     def __del__(self):
@@ -62,8 +65,8 @@ class JobServer(object):
         queue_task = self.job_methods[method.routing_key]
         func = queue_task['func']
         kwargs = queue_task['kwargs']
+        func(json.loads(body), **kwargs)
         ch.basic_ack(delivery_tag=method.delivery_tag)
-        return func(json.loads(body), **kwargs)
 
     def job_register(self):
         for key in self.job_methods.keys():
