@@ -31,5 +31,4 @@ def start():
     channel.basic_qos(prefetch_count=1)
     job_server = JobServer(channel, job_methods)
     job_server.job_register()
-
-    channel.start_consuming()
+    job_server.start()
